###################################################
### chunk number 1: foo
###################################################
options(keep.source = TRUE, width = 60)
foo <- packageDescription("raster")


###################################################
### chunk number 2: raster-1
###################################################
library(raster)
r <- raster()
r
r <- raster(ncol=36, nrow=18, xmn=-1000, xmx=1000, ymn=-100, ymx=900)
res(r)
res(r) <- 100
res(r)
ncol(r) <- 18
res(r)
projection(r) <- "+proj=utm +zone=48 +datum=WGS84"
r


###################################################
### chunk number 3: 
###################################################
r <- raster(system.file("external/test.grd", package="raster"))
plot(r)


###################################################
### chunk number 4: raster-2
###################################################
r1 <- raster(nrow=10, ncol=10)
# set random cell values 
r1 <- setValues(r1, runif(ncell(r1)))
r2 <- setValues(r1, runif(ncell(r1)))
r3 <- setValues(r1, runif(ncell(r1)))
# combine three RasterLayer objects into a RasterStack
s <- stack(r1, r2, r3)
s
nlayers(s)
# combine three RasterLayer objects into a RasterBrick
b1 <- brick(r1, r2, r3)
b2 <- brick(s)
# create a RasterBrick from file
b <- brick(system.file("external/rlogo.grd", package="raster"))
b
nlayers(b)
# extract a single RasterLayer
r <- raster(b, layer=2)
# equivalent to creating it from disk
r <- raster(system.file("external/rlogo.grd", package="raster"), band=2)


###################################################
### chunk number 5: raster-3
###################################################
r <- raster(ncol=36, nrow=18)
r[] <- 1:ncell(r)
s <- r + 1
s <- sqrt(s)
s <- s * r + 5
r[] <- round(runif(ncell(r))) 
r <- r == 1
s[r] <- -0.5
s[!r] <- 5
s[s == 5] <- runif(length(s[s==5]))
a <- sum(r,s)
b <- round(mean(r,s,10))
st <- stack(r, s, a, b)
sst <- sum(st)


###################################################
### chunk number 6: raster-5
###################################################
r <- raster()
r[] <- 1:ncell(r)
ra <- aggregate(r, 10)
r1 <- crop(r, extent(-180,0,0,30))
r2 <- crop(r, extent(-10,180,-20,10))
m <- merge(r1, r2, filename='test.grd', overwrite=TRUE)


###################################################
### chunk number 7: raster-6
###################################################
r <- raster(ncol=10, nrow=10)
r[] <- round(runif(ncell(r))*10)
s <- calc(r, function(x){ x[x < 2] <- NA; return(x)} )
t <- overlay(r, s, fun=function(x, y){ x / (2 * sqrt(y)) + 5 } )
u <- mask(r, t)
v = u==s
w <- cover(t, r)
x <- reclass(w, c(0,1,1,  1,5,2, 4,10,3))
y <- subs(w, data.frame(id=c(0,2), v=c(40,50)))


###################################################
### chunk number 8: raster-7
###################################################
r <- raster(ncol=36, nrow=18)
r[] <- runif(ncell(r))
cellStats(r, mean)
s = r
s[] <- round(runif(ncell(r)) * 5)
zonal(r,s,median)
freq(s)
count(s, 3)
crosstab(r*3, s)


###################################################
### chunk number 9: raster-8
###################################################
library(raster)
r <- raster(ncol=36, nrow=18)
ncol(r)
nrow(r)
ncell(r)
rowFromCell(r, 100)
colFromCell(r, 100)
cellFromRowCol(r,5,5)
xyFromCell(r, 100)
cellFromXY(r, c(0,0))
colFromX(r, 0)
rowFromY(r, 0)


###################################################
### chunk number 10: raster-10
###################################################
r <- raster(system.file("external/test.grd", package="raster"))
getValues(r, 50)[35:39]
getValuesBlock(r, 50, 1, 35, 5)


###################################################
### chunk number 11: raster-11
###################################################
cells <- cellFromRowCol(r, 50, 35:39)
cells
cellValues(r, cells)
xy = xyFromCell(r, cells)
xy
xyValues(r, xy)


###################################################
### chunk number 12: raster-12
###################################################
r[cells] 
r[1:4]
filename(r)
r[2:3] <- 10
r[1:4]
filename(r)


###################################################
### chunk number 13: raster-13
###################################################
r[1]
r[[1,1]]
r[[1:3,1:3]]
r[[75:90, 15]]


###################################################
### chunk number 14: raster-20
###################################################
r1 <- raster(ncol=36, nrow=18)
r2 <- r1
r1[] <- runif(ncell(r1))
r2[] <- runif(ncell(r1))
s <- stack(r1, r2)
sgdf <- as(s, 'SpatialGridDataFrame')
newr2 <- raster(sgdf, 2)
news <- stack(sgdf)


###################################################
### chunk number 15: raster-32
###################################################
setClass ('myRaster',
	contains = 'RasterLayer',
	representation (
		important = 'data.frame',
		essential = 'character'
	) ,
	prototype (
		important = data.frame(),
		essential = ''
	)
)
	
r = raster(nrow=10, ncol=10)

m <- as(r, 'myRaster')
m@important <- data.frame(id=1:10, value=runif(10))
m@essential <- 'my own slot'
m[] <- 1:ncell(m)
plot(m)


###################################################
### chunk number 16: raster-33
###################################################
setMethod ('show' , 'myRaster', 
	function(object) {
		callNextMethod(object) # call show(RasterLayer)
		cat('essential:', object@essential, '\n')
		cat('important information:\n')
		print( object@important)
	})	
	
m


